import * as prompts from "@clack/prompts";
import { handleCancel, handlePromptCancel } from "./prompts.js";
async function ensureRepositoryExists(octokit, owner, repository) {
  if (!octokit) {
    return repository;
  }
  while (true) {
    try {
      await octokit.rest.repos.get({
        owner,
        repo: repository
      });
      return repository;
    } catch (error) {
      if (error.status !== 404) {
        throw error;
      }
    }
    const selection = await prompts.select({
      message: `Repository ${repository} doesn't seem to exist under ${owner}. What would you like to do?`,
      options: [
        { label: "Bail out and maybe try again later", value: "bail" },
        { label: "Create a new repository", value: "create" },
        {
          label: "Try again with a different repository",
          value: "different"
        }
      ]
    });
    handlePromptCancel(selection);
    switch (selection) {
      case "bail":
        handleCancel();
        break;
      case "create":
        await octokit.rest.repos.createUsingTemplate({
          name: repository,
          owner,
          template_owner: "JoshuaKGoldberg",
          template_repo: "template-typescript-node-package"
        });
        break;
      case "different":
        const newRepository = await prompts.text({
          message: `What would you like to call the repository?`
        });
        handlePromptCancel(newRepository);
        repository = newRepository;
        break;
    }
  }
}
export {
  ensureRepositoryExists
};
//# sourceMappingURL=ensureRepositoryExists.js.map