import chalk from "chalk";
import { execaCommand } from "execa";
import { logLine } from "../shared/cli/lines.js";
import { withSpinner } from "../shared/cli/spinners.js";
async function runCommands(label, commands) {
  const failed = [];
  await withSpinner(label, async () => {
    for (const command of commands) {
      try {
        await execaCommand(command);
      } catch {
        failed.push(command);
      }
    }
  });
  if (!failed.length) {
    return;
  }
  logLine();
  for (const command of failed) {
    logLine(
      [
        chalk.yellow(`\u{1F7E1} Running \``),
        chalk.yellowBright(command),
        chalk.yellow(`\` failed. You should run it and fix its complaints.`)
      ].join("")
    );
  }
}
export {
  runCommands
};
//# sourceMappingURL=runCommands.js.map